/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "../logunit.h"
#include <log4cxx/helpers/syslogwriter.h>

using namespace log4cxx;
using namespace log4cxx::helpers;


LOGUNIT_CLASS(SyslogWriterTest)
{
	LOGUNIT_TEST_SUITE(SyslogWriterTest);
	LOGUNIT_TEST(testUnknownHost);
	LOGUNIT_TEST_SUITE_END();

public:
	/**
	 * Tests writing to an unknown host.
	 */
	void testUnknownHost()
	{
		SyslogWriter writer(LOG4CXX_STR("unknown.invalid"));
		writer.write(LOG4CXX_STR("Hello, Unknown World."));
	}

};


LOGUNIT_TEST_SUITE_REGISTRATION(SyslogWriterTest);

